=======
Gallery
=======

:meth:`~mpl_interactions.interactive_plot`

.. image:: images/basic-example.gif

:meth:`~mpl_interactions.interactive_hist`

.. image:: _static/basic-hist.gif

:meth:`~mpl_interactions.heatmap_slicer`

.. image:: images/heatmap_slicer.gif

:meth:`~mpl_interactions.zoom_factory` and :meth:`~mpl_interactions.panhandler`

.. image:: images/zoom-and-pan.gif

:class:`~mpl_interactions.image_segmenter`

.. image:: _static/segment.gif
